@@ -78,7 +78,6 @@ class StatusCastAPIDriver:
         self.username = username
         self.base_url = base_url
         self.verify_ssl = verify_ssl
-        self.auth_session = self.initialize_session()
 
 
 
@@ -121,11 +120,15 @@ class StatusCastAPIDriver:
                                                 )
         # Don't need to store this as instance variable, it's
         # implicitly stored with session
-        access_token = json.loads(r.content)['access_token']
-
+        try:
+            access_token = r.json()['access_token']
+        except:
+            print("Access token was not in response: response was {}".format(r.content))
+            access_token = ""
         # Use session to always include "Authorization": "Bearer " + token as default header
         # Now this token is passed for all additional API calls inherently
         auth_session.headers.update({'Authorization': 'Bearer {}'.format(access_token)})
+        self.auth_session = auth_session
         return auth_session
 
 
